LocalSignalsRuntime

Struct LocalSignalsRuntime 

pub struct LocalSignalsRuntime;
A plain SignalsRuntimeRef implementation that represents a static signals runtime.

๐Ÿšง This implementation is currently not optimised. ๐Ÿšง

Features

Enable the local_signals_runtime Cargo feature to implement SignalsRuntimeRef for this type.

Logic

This runtime is guaranteed to have settled whenever the last thread-local borrow of it ceases, but only regarding effects originating on the current thread.

(This means that in addition to transiently borrowing calls, returned Futures may cause the LocalSignalsRuntime not to settle until they are dropped.)

Otherwise, it makes no additional guarantees over those specified in SignalsRuntimeRefโ€™s documentation.

Panics

SignalsRuntimeRef::Symbols associated with the LocalSignalsRuntime are ordered.
Given LSRSymbols a and b, b can depend on a only iff a < b (by creation order).